@@ -97,8 +97,10 @@ describe 'heat::api_cfn' do
 
     context 'with $sync_db set to false in ::heat' do
       let :pre_condition do
-        "class {'heat':
-           keystone_password => 'password',
+        "class { '::heat::keystone::authtoken':
+           password => 'a_big_secret',
+         }
+         class {'heat':
            sync_db => false
          }"
       end
